/* ExtractStudentRecords.cmd  20020319.2

   Extract Students from School Records

   Extract student/parent names from the label records from school.  The records were exported
   in a fixed (41 col. per) record format.

   Requires data file: 2001Stus.txt to be in the same directory.

   Debugged: Yes
*/

/* open the raw data file for reading */
RawDataFile = "2001Stus.txt"  /* hard wire for now - use arg later */
OneRawDataLine = linein(RawDataFile)  /* this line of raw data is column headings */

/* read in the raw data */
numStu = 0
do while lines(RawDataFile)
  numStu = numStu + 1
  OneRawDataLine = linein(RawDataFile)  /* this line is real data */

  /* parse the raw data line */
  parse value OneRawDataLine with ,
                Chunk.numStu.FName     41 42  ,
                Chunk.numStu.LName     82 83  ,
                Chunk.numStu.Addreess 123 124 ,
                Chunk.numStu.City     164 165 ,
                Chunk.numStu.Zip      205 206 ,
                Chunk.numStu.HomeFone 246 247 ,
                .                     287 288 ,
                Chunk.numStu.Parent   328 329 ,
                .

  /* remove extraneous spaces */
  Chunk.numStu.FName    = strip(Chunk.numStu.FName)
  Chunk.numStu.LName    = strip(Chunk.numStu.LName)
  Chunk.numStu.Addreess = strip(Chunk.numStu.Addreess)
  Chunk.numStu.City     = strip(Chunk.numStu.City)
  Chunk.numStu.Zip      = strip(Chunk.numStu.Zip)
  Chunk.numStu.HomeFone = strip(Chunk.numStu.HomeFone)
  Chunk.numStu.Parent   = strip(Chunk.numStu.Parent)

end

/* save the number of students in the stem */
Chunk.0 = numStu

/* create an HTML document */
say '<!doctype html public "-//w3c//dtd html 4.0 transitional//en">'
say '<html>'
say '<head>'
say '   <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">'
say '   <meta name="Author" content="Sheridan">'
say '   <meta name="GENERATOR" content="Mozilla/4.61 [en] (OS/2; U) [Netscape]">'
say '   <title>Eastside High Schoolers as of' date() '</title>'
say '</head>'
say
say '<body>'

say '<center><h1>Eastside High Schoolers</h1></center>'
say '<center><h4>As of' date() '</h4></center>'

say '<p />'

/* create and populate a table */
do OuterLoop = 1 to Chunk.0 by 33
  say '<table border="1" width="100%" cols="3" cellpadding="5">'

  do InnerLoop = 0 to 10

    /* column 1 */
    i = OuterLoop + InnerLoop
    if i > Chunk.0 then iterate
    say '  <tr>'
    say '    <td>'
    say '      <dl>'
    say '        <dt>' || Chunk.i.FName Chunk.i.LName || '</dt>'
    say '          <dd>' || Chunk.i.Parent || '</dd>'
    say '          <dd>' || Chunk.i.HomeFone || '</dd>'
    say '      </dl>'
    say '    </td>'

    /* column 2 */
    i = i + 11
    if i > Chunk.0 then iterate
    say '    <td>'
    say '      <dl>'
    say '        <dt>' || Chunk.i.FName Chunk.i.LName || '</dt>'
    say '          <dd>' || Chunk.i.Parent || '</dd>'
    say '          <dd>' || Chunk.i.HomeFone || '</dd>'
    say '      </dl>'
    say '    </td>'

    /* column 3 */
    i = i + 11
    if i > Chunk.0 then iterate
    say '    <td>'
    say '      <dl>'
    say '        <dt>' || Chunk.i.FName Chunk.i.LName || '</dt>'
    say '          <dd>' || Chunk.i.Parent || '</dd>'
    say '          <dd>' || Chunk.i.HomeFone || '</dd>'
    say '      </dl>'
    say '    </td>'

    say '  </tr>'

  end /* do InnerLoop = 1 to 11 */

  say '</table>'

  say '<p />&nbsp; <p />&nbsp;' /* make sure the next table goes on the next page */
end /* do OuterLoop = 1 to Chunck.0 */



