/* PiNumbersTable.cmd  20020319.2

   This program creates a table that gives the product of a numerator (a) and Pi (3.14159265359)
   divided by a denominator (b).  When the zeros of a function are determined on a graphing
   calculator, the x-value of a zero displayed by the calculator can be sought in the body of
   the table and then the numerator (a) and denominator (b) can be determined from the borders
   of the table allowing the answer to be written as: A times Pi over B (a x Pi/b).

*/

/* create an HTML document */
say '<!doctype html public "-//w3c//dtd html 4.0 transitional//en">'
say '<html>'
say '<head>'
say '   <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">'
say '   <meta name="Author" content="Sheridan George">'
say '   <meta name="GENERATOR" content="Mozilla/4.61 [en] (OS/2; U) [Netscape]">'
say '   <title>Perfect Multiples</title>'
say '</head>'
say
say '<body>'

say '<center><h1>Pi Numbers</h1></center>'

say '<p />'

say 'When using a graphing calculator to find the zeros of a curve, the x-value is given in decimal.',
     'If one needs to report the x-value as a rational number times Pi it can become troublesome',
     'to make the conversion especially if the numerator and denominator of the rational number ',
     'is quite large.  This chart comes to the rescue.'
say '<p />'
say 'To convert a decimal x-value to a rational number times Pi, look for the x-value in the ',
     'body of the chart.  When the x-value, or a close approximation, is found, the Pi number ',
     'at the top of the chart will be the numerator of the rational number and the number ',
     'at the left side of the chart will be the denominator.'
say '<p />'

/* initialize Pi */
Pi = 3.14159265359

/* initialize loop parameters */
a1LoopLimit = 10
b1LoopLimit = 20

/* create and populate a table - Note: cols= must be 1 greater than a1LoopLimit limit */
say '<table border="1" width="100%" cols="' || a1LoopLimit+1 || '" cellpadding="3">'

/* put the 'a' term headings in the table */
say '  <tr align="center">'
say '    <td width="3%"></td>'  /* first cell in the heading row is blank */

do a = 1 to a1LoopLimit
  say '    <td>' || a || ' Pi</td>'
end /* do a=1 ... */
say '  </tr>'

do b = 1 to b1LoopLimit
  say '  <tr>' /* start a new row in the table */
  say '    <td align="center">' || b || '</td>' /* first cell in each row contains the b term */
  do a = 1 to a1LoopLimit  /* fill the rest of the cells */
    cell = (a * Pi) / b
    if b > 1 then
      select
        when a = b then say '    <td>&nbsp;</td>'
        when a // b = 0 then say '    <td>&nbsp;</td>'
        when b // a = 0 & a > 1 then say '    <td>&nbsp;</td>'
        otherwise say '    <td>' || cell || '</td>'
      end /* select*/
    else say '    <td>' || cell || '</td>'
  end /* do a = 1 to 5 */
  say '  </tr>' /* end a new row in the table */
end /* do b = 1 to 5 */
say '</table>'

/* create another table for ther reverse side of the paper */
say '<p />&nbsp; <p />&nbsp;  <!-- force a new page when the tables are printed on paper -->'

/* initialize loop parameters */
a2LoopStart = a1LoopLimit + 1
a2LoopLimit = 2 * a1LoopLimit
b2LoopStart = 1
b2LoopLimit = b1LoopLimit

/* create and populate a table - Note: cols= must be 1 greater than a2LoopLimit limit */
say '<table border="1" width="100%" cols="' || a2LoopLimit+1 || '" cellpadding="3">'

/* put the 'a' term headings in the table */
say '  <tr align="center">'
say '    <td width="3%"></td>'  /* first cell in the heading row is blank */

do a = a2LoopStart to a2LoopLimit
  say '    <td>' || a || ' Pi</td>'
end /* do a=1 ... */
say '  </tr>'

do b = b2LoopStart to b2LoopLimit
  say '  <tr>' /* start a new row in the table */
  say '    <td align="center">' || b || '</td>' /* first cell in each row contains the b term */
  do a = a2LoopStart to a2LoopLimit  /* fill the rest of the cells */
    cell = (a * Pi) / b
    if b > 1 then
      select
        when a = b then say '    <td>&nbsp;</td>'
        when a // b = 0 then say '    <td>&nbsp;</td>'
        when b // a = 0 & a > 1 then say '    <td>&nbsp;</td>'
        otherwise say '    <td>' || cell || '</td>'
      end /* select*/
    else say '    <td>' || cell || '</td>'
  end /* do a = 1 to 5 */
  say '  </tr>' /* end a new row in the table */
end /* do b = 1 to 5 */

say '</table>'
say '</body>'

say '</html>'


